package com.lzmispt.data.resource.service.file.impl;

package .tmp;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.lzmispt.core.entity.dto.authorize.UserInfoDTO;
import com.lzmispt.core.service.authorize.impl.AuthorizeImpl;
import com.lzmispt.data.center.entity.dto.log.CommonLogDTO;
import com.lzmispt.data.center.entity.dto.standard.metadata.MetadataEntityDataItemDTO;
import com.lzmispt.data.center.entity.enums.StatusCodeEnum;
import com.lzmispt.data.center.entity.vo.resource.datasource.DataSourceVO;
import com.lzmispt.data.center.entity.vo.standard.codetable.MetadataCommonCodeVO;
import com.lzmispt.data.center.entity.vo.standard.metadata.MetadataEntityDataItemVO;
import com.lzmispt.data.center.entity.vo.standard.rule.RuleConfigVO;
import com.lzmispt.data.resource.client.DataInterfaceClient;
import com.lzmispt.data.resource.client.DataStandardClient;
import com.lzmispt.data.resource.dao.file.IFileInfoFieldDao;
import com.lzmispt.data.resource.dao.file.IFileInfoTableDao;
import com.lzmispt.data.resource.entity.dto.metadata.BatchCheckDataItemNameParamDTO;
import com.lzmispt.data.resource.entity.dto.metadata.CheckDataItemNameDTO;
import com.lzmispt.data.resource.entity.po.file.FileInfoFieldPO;
import com.lzmispt.data.resource.entity.po.file.FileInfoTablePO;
import com.lzmispt.data.resource.service.file.IImportFileInfoField;
import com.lzmispt.data.resource.service.file.impl.FileInfoFieldManager;
import com.lzmispt.dcbase.ServiceUtil;
import com.lzmispt.dcbase.database.IManage;
import com.lzmispt.dcbase.dcconst.DCConst;
import com.lzmispt.dcbase.sysfield.SysFieldHelper;
import com.lzmispt.dcbase.util.FieldValidateUtil;
import com.lzmispt.dcbase.util.HeaderInterceptor;
import com.lzmispt.framework.entity.entity.ResultEntity;
import com.lzmispt.framework.entity.vo.ErrorCellInfo;
import com.lzmispt.framework.exception.ExceptionUtil;
import com.lzmispt.framework.fconst.FrameConst;
import com.lzmispt.framework.utils.ExcelUtil;
import com.lzmispt.framework.utils.RabbitMQUtil;
import com.lzmispt.framework.utils.WorkerId;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.function.Function;
import java.util.regex.Pattern;
import java.util.stream.Collectors;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;
import org.springframework.web.multipart.MultipartFile;

public abstract class ImportFileInfoFieldManager implements IImportFileInfoField, IManage {
  private static final String IS_EXIST = "】已存在";
  
  private static final String DATA_ITEM_NAME = "物理字段名称【";
  
  private static final String CHECK_MSG = "】为主键时不能和文件表内置字段相同";
  
  private static final String FIELD_CODE = "字段编码【";
  
  private static final String BUNINESS_PK_FIELD_NAME = "业务主键";
  
  private static final String ORDER_FIELD_NAME = "序号";
  
  private static final List<String> COMMON_FIELD_NAMES = Arrays.asList(new String[] { 
        "序号", "字段编码", "字段名称", "物理字段名", "数据类型", "业务主键", "必填", "数据元", "值域", "验证规则", 
        "字段说明" });
  
  public static final int ROW_COUNT = 500;
  
  public static final List<String> PRIMARY_KEY_VALUES = Arrays.asList(new String[] { "是", "否" });
  
  public static final String IMPORT_EXCEL_NAME = "数据存储导入模板";
  
  @Autowired
  AuthorizeImpl authorize;
  
  @Autowired
  DataStandardClient dataStandardClient;
  
  @Autowired
  DataInterfaceClient dataInterfaceClient;
  
  public ResultEntity importFileInfoFieldByExcel(HttpServletResponse response, MultipartFile file, Long fileTableId, Integer nodeType, Integer dataCategory, String platCode, String tokenId) {
    XSSFWorkbook xSSFWorkbook;
    Workbook workbook = null;
    try {
      xSSFWorkbook = new XSSFWorkbook(file.getInputStream());
    } catch (Exception ex) {
      logErrorInfo(ExceptionUtil.getStackTraceMsg(ex), "从文件流中读取excel异常", platCode, tokenId);
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_STANDARD_IMPORT_EXCEL_DATA_ERROR_FIELD.getCode()), StatusCodeEnum.DATA_STANDARD_IMPORT_EXCEL_DATA_ERROR_FIELD.getMessage());
    } 
    FileInfoTablePO fileInfoTablePO = ((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).selectFileInfoTable(fileTableId);
    Map<FileInfoTablePO, List<Map<String, String>>> fileInfoTableWithSheet = new HashMap<>();
    try {
      ResultEntity getFileInfoTableWithSheetRet = getFileInfoTableWithSheet((Workbook)xSSFWorkbook, file, fileInfoTablePO, platCode);
      if (!getFileInfoTableWithSheetRet.getCode().equals(Integer.valueOf(0)))
        return getFileInfoTableWithSheetRet; 
      if (getFileInfoTableWithSheetRet.getObj() == null)
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_IMPORT_EXCEL_NO_SHEET_ERROR.getCode()), StatusCodeEnum.DATA_RESOURCE_IMPORT_EXCEL_NO_SHEET_ERROR.getMessage()); 
      fileInfoTableWithSheet = (Map<FileInfoTablePO, List<Map<String, String>>>)getFileInfoTableWithSheetRet.getObj();
      if (fileInfoTableWithSheet.keySet().size() == 0)
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_STANDARD_IMPORT_EXCEL_DATA_NO_DATA.getCode()), StatusCodeEnum.DATA_STANDARD_IMPORT_EXCEL_DATA_NO_DATA.getMessage()); 
    } catch (Exception ex) {
      logErrorInfo(ExceptionUtil.getStackTraceMsg(ex), "读取excel工作簿数据异常", platCode, tokenId);
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_IMPORT_EXCEL_DATA_GET_SHEET_ERROR.getCode()), StatusCodeEnum.DATA_RESOURCE_IMPORT_EXCEL_DATA_GET_SHEET_ERROR.getMessage());
    } 
    Map<String, Map<String, Object>> allResult = new HashMap<>();
    int allDataCount = 0;
    try {
      List<RuleConfigVO> allRules = (List<RuleConfigVO>)this.dataStandardClient.getAllRuleConfigNameAndScope(platCode, tokenId).getObj();
      UserInfoDTO userInfoDTO = this.authorize.getUserInfoByTokenId(tokenId);
      MetadataEntityDataItemDTO metadataEntityDataItemDTO = new MetadataEntityDataItemDTO();
      metadataEntityDataItemDTO.setUserId(userInfoDTO.getUserId());
      metadataEntityDataItemDTO.setOrganizationId(userInfoDTO.getOrganizationId());
      Map<String, List<FileInfoFieldPO>> sheetWithFields = new HashMap<>();
      for (FileInfoTablePO fileTable : fileInfoTableWithSheet.keySet()) {
        List<Map<String, String>> sheetData = fileInfoTableWithSheet.get(fileTable);
        List<Map<String, String>> tempSheetData = new ArrayList<>();
        for (Map<String, String> data : sheetData) {
          if (data != null) {
            boolean isEmpty = true;
            for (Map.Entry<String, String> entry : data.entrySet()) {
              if (!StringUtils.isEmpty(entry.getValue()))
                isEmpty = false; 
              if ("序号".equalsIgnoreCase(entry.getKey()) && !StringUtils.isEmpty(entry.getValue()))
                try {
                  int num = Double.valueOf(entry.getValue()).intValue();
                  entry.setValue(num + "");
                } catch (Exception exception) {} 
            } 
            if (!isEmpty) {
              tempSheetData.add(data);
              allDataCount++;
            } 
          } 
        } 
        sheetData = tempSheetData;
        if (fileInfoTablePO != null) {
          Map<String, Object> convertResult = convertToFileInfoFieldList(sheetData, fileTable, tokenId, userInfoDTO, allRules, fileTable.getFileTableCnName(), sheetWithFields);
          allResult.put(fileTable.getFileTableCnName(), convertResult);
        } 
      } 
    } catch (Exception ex) {
      logErrorInfo(ExceptionUtil.getStackTraceMsg(ex), "验证导入数据错误", platCode, tokenId);
      return 
        ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_IMPORT_EXCEL_DATA_VALIDATE_SHEET_ERROR.getCode()), StatusCodeEnum.DATA_RESOURCE_IMPORT_EXCEL_DATA_VALIDATE_SHEET_ERROR.getMessage());
    } 
    return handleResult(allResult, platCode, tokenId, allDataCount);
  }
  
  private ResultEntity handleResult(Map<String, Map<String, Object>> allResult, String platCode, String tokenId, int allDataCount) {
    List<String> errorMsgList = new ArrayList<>();
    List<FileInfoFieldPO> fileInfoFieldPOList = new ArrayList<>();
    List<MetadataEntityDataItemDTO> metadataEntityDataItemDTOList = new ArrayList<>();
    int errorCount = 0;
    int needImportCount = 0;
    for (String key : allResult.keySet()) {
      Map<String, Object> ret = allResult.get(key);
      Boolean isSuccess = (Boolean)ret.get("isSuccess");
      needImportCount += ((Integer)ret.get("needImportCount")).intValue();
      if (!isSuccess.booleanValue()) {
        errorCount += ((Integer)ret.get("errorRowCount")).intValue();
        errorMsgList.addAll((List)ret.get("errorInfo"));
        continue;
      } 
      List<FileInfoFieldPO> importFileInfoFields = (List<FileInfoFieldPO>)ret.get("importFileInfoField");
      fileInfoFieldPOList.addAll(importFileInfoFields);
      List<MetadataEntityDataItemDTO> importDataItems = (List<MetadataEntityDataItemDTO>)ret.get("importDataItem");
      metadataEntityDataItemDTOList.addAll(importDataItems);
    } 
    try {
      addFileInfoFieldAndDataItemByImport(fileInfoFieldPOList, metadataEntityDataItemDTOList, platCode, tokenId);
    } catch (Exception ex) {
      logErrorInfo(ExceptionUtil.getStackTraceMsg(ex), "通过excel导入字段失败", platCode, tokenId);
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_STANDARD_IMPORT_EXCEL_DATA_WRITE_SHEET_ERROR.getCode()), StatusCodeEnum.DATA_STANDARD_IMPORT_EXCEL_DATA_WRITE_SHEET_ERROR.getMessage());
    } 
    Map<String, Object> result = new HashMap<>();
    result.put("dataCount", Integer.valueOf(allDataCount));
    result.put("needImportCount", Integer.valueOf(needImportCount));
    result.put("errorRowCount", Integer.valueOf(errorCount));
    result.put("errorInfo", errorMsgList);
    result.put("isSuccess", Boolean.valueOf(true));
    if (errorCount > 0)
      result.put("isSuccess", Boolean.valueOf(false)); 
    return ResultEntity.successMessage(result);
  }
  
  private void addFileInfoFieldAndDataItemByImport(List<FileInfoFieldPO> fileInfoFieldPOList, List<MetadataEntityDataItemDTO> metadataEntityDataItemDTOList, String platCode, String tokenId) throws Exception {
    List<Long> addFileInfoFieldIds = new ArrayList<>();
    Boolean isAddDataItems = (Boolean)this.dataStandardClient.batchAddMetadataEntityDataItemList(metadataEntityDataItemDTOList, platCode, tokenId).getObj();
    if (!isAddDataItems.booleanValue())
      throw new Exception("新增数据元失败"); 
    for (int i = 0; i < fileInfoFieldPOList.size(); i++) {
      int num = ((IFileInfoFieldDao)ServiceUtil.getFileInfoFieldDao(getDefaultCode(), IFileInfoFieldDao.class)).insertFileInfoField(fileInfoFieldPOList.get(i));
      if (num > 0) {
        addFileInfoFieldIds.add(((FileInfoFieldPO)fileInfoFieldPOList.get(i)).getFieldId());
        this.dataStandardClient.updateInstanceCount(((FileInfoFieldPO)fileInfoFieldPOList.get(i)).getDataItemId(), true, getDefaultCode(), tokenId);
      } else {
        for (Long item : addFileInfoFieldIds)
          ((IFileInfoFieldDao)ServiceUtil.getFileInfoFieldDao(getDefaultCode(), IFileInfoFieldDao.class)).deleteFileInfoField(item); 
        throw new Exception("新增文件表字段失败");
      } 
    } 
  }
  
  private Map<String, Object> convertToFileInfoFieldList(List<Map<String, String>> sheetData, FileInfoTablePO fileInfoTablePO, String tokenId, UserInfoDTO userInfoDTO, List<RuleConfigVO> allRules, String sheetName, Map<String, List<FileInfoFieldPO>> sheetWithItems) {
    Map<String, Object> result = new HashMap<>();
    Integer importCount = Integer.valueOf(0);
    Integer errorRowCount = Integer.valueOf(0);
    List<FileInfoFieldPO> insertFileInfoFieldPOS = new ArrayList<>();
    sheetWithItems.put(sheetName, insertFileInfoFieldPOS);
    List<FileInfoFieldPO> infoFieldPOListFromDb = ((IFileInfoFieldDao)ServiceUtil.getFileInfoFieldDao(getDefaultCode(), IFileInfoFieldDao.class)).selectFileInfoFieldsByFileTableId(fileInfoTablePO.getFileTableId());
    List<MetadataEntityDataItemDTO> dataItemDTOList = new ArrayList<>();
    List<ErrorCellInfo> errorInfo = new ArrayList<>();
    for (int i = 0; i < sheetData.size(); i++) {
      Map<String, String> row = sheetData.get(i);
      if (row != null) {
        FileInfoFieldPO fileInfoFieldPO = new FileInfoFieldPO();
        MetadataEntityDataItemDTO metadataEntityDataItemDTO = new MetadataEntityDataItemDTO();
        fileInfoFieldPO.setIsReference(DCConst.FALSE);
        metadataEntityDataItemDTO.setDataItemType("0");
        Boolean isHaveError = Boolean.valueOf(false);
        List<ErrorCellInfo> checkResult = checkFieldError(fileInfoTablePO, fileInfoFieldPO, metadataEntityDataItemDTO, insertFileInfoFieldPOS, i + 1, row, tokenId, allRules, sheetData, infoFieldPOListFromDb, sheetWithItems, sheetName);
        if (!checkResult.isEmpty()) {
          Integer integer1 = errorRowCount, integer2 = errorRowCount = Integer.valueOf(errorRowCount.intValue() + 1);
          isHaveError = Boolean.valueOf(true);
          errorInfo.addAll(checkResult);
        } 
        if (!isHaveError.booleanValue()) {
          Integer integer1 = importCount, integer2 = importCount = Integer.valueOf(importCount.intValue() + 1);
          if (metadataEntityDataItemDTO.getDataItemId() == null) {
            metadataEntityDataItemDTO.setDataItemId((Long)WorkerId.getNextId(Long.class));
            dataItemDTOList.add(metadataEntityDataItemDTO);
          } else {
            fileInfoFieldPO.setIsReference(DCConst.TRUE);
          } 
          fileInfoFieldPO.setDataItemId(metadataEntityDataItemDTO.getDataItemId());
          fileInfoFieldPO.setIsDelete(DCConst.FALSE);
          fileInfoFieldPO.setOrganizationId(fileInfoTablePO.getOrganizationId());
          fileInfoFieldPO.setUserId(userInfoDTO.getUserId());
          fileInfoFieldPO.setFieldId((Long)WorkerId.getNextId(Long.class));
          fileInfoFieldPO.setFieldStatus(DCConst.FileFieldStatus.NONE);
          fileInfoFieldPO.setFileTableId(fileInfoTablePO.getFileTableId());
          fileInfoFieldPO.setIsSystem(DCConst.FALSE);
          fileInfoFieldPO.setCreateTime(new Date());
          insertFileInfoFieldPOS.add(fileInfoFieldPO);
        } 
      } 
    } 
    result.put("dataCount", Integer.valueOf(sheetData.size()));
    result.put("needImportCount", importCount);
    result.put("errorRowCount", errorRowCount);
    if (!errorInfo.isEmpty()) {
      result.put("isSuccess", Boolean.valueOf(false));
      List<String> errorMsgList = new ArrayList<>();
      for (int j = 0; j < errorInfo.size(); j++)
        errorMsgList.add("工作簿【" + fileInfoTablePO.getFileTableCnName() + "】，第" + ((ErrorCellInfo)errorInfo.get(j)).getRowIndex() + "行，第" + ((ErrorCellInfo)errorInfo.get(j)).getColumnIndex() + "列，" + ((ErrorCellInfo)errorInfo.get(j)).getMsg()); 
      result.put("errorInfo", errorMsgList);
      return result;
    } 
    result.put("isSuccess", Boolean.valueOf(true));
    result.put("importFileInfoField", insertFileInfoFieldPOS);
    result.put("importDataItem", dataItemDTOList);
    return result;
  }
  
  private List<ErrorCellInfo> checkFieldError(FileInfoTablePO fileInfoTablePO, FileInfoFieldPO fileInfoFieldPO, MetadataEntityDataItemDTO metadataEntityDataItemDTO, List<FileInfoFieldPO> insertFileInfoFieldPOS, int rowIndex, Map<String, String> row, String tokenId, List<RuleConfigVO> allRules, List<Map<String, String>> sheetData, List<FileInfoFieldPO> infoFieldPOListFromDb, Map<String, List<FileInfoFieldPO>> sheetWithItems, String sheetName) {
    List<ErrorCellInfo> errorInfo = new ArrayList<>();
    int columnIndex = 1;
    List<String> fieldNames = new ArrayList<>(COMMON_FIELD_NAMES);
    Integer isPrimaryKey = getBoolFieldValue("业务主键", row);
    DataSourceVO dataSourceVO = null;
    if (fileInfoTablePO.getDataSourceId() != null)
      dataSourceVO = (DataSourceVO)this.dataStandardClient.getDataSourceInfoDoNotDecryptById(fileInfoTablePO.getDataSourceId(), getDefaultCode(), tokenId).getObj(); 
    MetadataEntityDataItemVO metadataEntityDataItemVO = getMetadataEntityDataItemByDataItemCode(row, tokenId);
    if (metadataEntityDataItemVO != null)
      BeanUtils.copyProperties(metadataEntityDataItemVO, metadataEntityDataItemDTO); 
    for (String name : fieldNames) {
      ErrorCellInfo errorCell = new ErrorCellInfo();
      errorCell.setColumnIndex(-1);
      errorCell.setRowIndex(rowIndex + 1);
      String value = row.get(name);
      errorCell = checkAllField(fileInfoFieldPO, metadataEntityDataItemDTO, fileInfoTablePO, value, errorCell, rowIndex, columnIndex, name, isPrimaryKey, dataSourceVO, insertFileInfoFieldPOS, row, tokenId, allRules, sheetData, infoFieldPOListFromDb, sheetWithItems, sheetName);
      if (errorCell.getColumnIndex() >= 0)
        errorInfo.add(errorCell); 
      columnIndex++;
    } 
    return errorInfo;
  }
  
  private ErrorCellInfo checkAllField(FileInfoFieldPO fileInfoFieldPO, MetadataEntityDataItemDTO metadataEntityDataItemDTO, FileInfoTablePO fileInfoTablePO, String value, ErrorCellInfo errorCell, int rowIndex, int columnIndex, String name, Integer isPrimaryKey, DataSourceVO dataSourceVO, List<FileInfoFieldPO> fileInfoFieldPOList, Map<String, String> row, String tokenId, List<RuleConfigVO> allRules, List<Map<String, String>> sheetData, List<FileInfoFieldPO> fileInfoFieldPOListFromDb, Map<String, List<FileInfoFieldPO>> sheetWithItems, String sheetName) {
    Integer isRequired;
    switch (name) {
      case "字段编码":
        errorCell = checkFieldCode(fileInfoFieldPO, fileInfoTablePO, value, errorCell, rowIndex, columnIndex, name, sheetData, sheetWithItems, sheetName);
        break;
      case "字段名称":
        if (StringUtils.isEmpty(value) && metadataEntityDataItemDTO.getDataItemId() != null)
          value = metadataEntityDataItemDTO.getDataItemCnName(); 
        errorCell = checkExcelFileInfoFieldName(fileInfoFieldPO, value, isPrimaryKey, errorCell, columnIndex, name, fileInfoFieldPOList, fileInfoFieldPOListFromDb);
        break;
      case "字段说明":
        if (StringUtils.isEmpty(value) && metadataEntityDataItemDTO.getDataItemId() != null)
          value = metadataEntityDataItemDTO.getDescription(); 
        if (StringUtils.hasText(value)) {
          String msg = FieldValidateUtil.checkFieldDescriptionLength(value, name);
          if (StringUtils.hasText(msg)) {
            errorCell.setColumnIndex(columnIndex);
            errorCell.setMsg(msg);
            break;
          } 
          fileInfoFieldPO.setDescription(value);
        } 
        break;
      case "物理字段名":
        if (StringUtils.isEmpty(value) && metadataEntityDataItemDTO.getDataItemId() != null)
          value = metadataEntityDataItemDTO.getDataItemName(); 
        errorCell = checkDataItemName(fileInfoFieldPO, metadataEntityDataItemDTO, fileInfoTablePO, value, errorCell, columnIndex, name, isPrimaryKey, dataSourceVO, fileInfoFieldPOList);
        break;
      case "数据类型":
        if (metadataEntityDataItemDTO.getDataItemId() == null)
          errorCell = FieldValidateUtil.checkDataType(metadataEntityDataItemDTO, value, errorCell, columnIndex, name); 
        fileInfoFieldPO.setFieldType(metadataEntityDataItemDTO.getDataType());
        fileInfoFieldPO.setFieldLength(metadataEntityDataItemDTO.getDataLength());
        fileInfoFieldPO.setFieldScale(metadataEntityDataItemDTO.getDataScale());
        break;
      case "业务主键":
        if (isPrimaryKey != null && (isPrimaryKey.intValue() == 0 || isPrimaryKey.intValue() == 1)) {
          fileInfoFieldPO.setIsPrimaryKey(isPrimaryKey);
          fileInfoFieldPO.setIsRequired(isPrimaryKey);
          break;
        } 
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg(name + "的值有误");
        break;
      case "必填":
        isRequired = null;
        if (isPrimaryKey != null && isPrimaryKey.intValue() == 1) {
          isRequired = isPrimaryKey;
        } else {
          isRequired = getBoolFieldValue("必填", row);
        } 
        if (isRequired != null && (isRequired.intValue() == 0 || isRequired.intValue() == 1)) {
          fileInfoFieldPO.setIsRequired(isRequired);
          break;
        } 
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg(name + "的值有误");
        break;
      case "值域":
        errorCell = checkDataRange(fileInfoFieldPO, metadataEntityDataItemDTO, value, errorCell, columnIndex, tokenId);
        break;
      case "验证规则":
        errorCell = checkDataRule(fileInfoFieldPO, metadataEntityDataItemDTO, value, errorCell, columnIndex, allRules);
        break;
      case "数据元":
        errorCell = checkMetadataEntityDataItemCode(fileInfoFieldPO, value, errorCell, columnIndex, metadataEntityDataItemDTO, row);
        break;
      case "序号":
        errorCell = checkFileInfoFieldOrder(fileInfoFieldPO, value, errorCell, columnIndex, name, row, sheetData, fileInfoFieldPOListFromDb);
        break;
    } 
    return errorCell;
  }
  
  private ErrorCellInfo checkDataRule(FileInfoFieldPO fileInfoFieldPO, MetadataEntityDataItemDTO metadataEntityDataItemPO, String value, ErrorCellInfo errorCell, int columnIndex, List<RuleConfigVO> allRules) {
    if (StringUtils.isEmpty(value) && metadataEntityDataItemPO.getDataItemId() != null) {
      fileInfoFieldPO.setDataRule(metadataEntityDataItemPO.getDataRule());
    } else if (!StringUtils.isEmpty(value)) {
      String errMsg = FieldValidateUtil.checkDataRule(value, allRules);
      if (!StringUtils.isEmpty(errMsg)) {
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg(errMsg);
      } else {
        String[] ruleStrs = value.split("、");
        String dataRuleStr = "";
        List<String> errorRules = new ArrayList<>();
        boolean isHaveScope = false;
        int i;
        for (i = 0; i < ruleStrs.length; i++) {
          String ruleName = ruleStrs[i];
          RuleConfigVO ruleConfigVO = allRules.stream().filter(r -> r.getName().equals(ruleName)).findFirst().orElse(null);
          if (ruleConfigVO != null && ruleConfigVO.getScope() != null && !ruleConfigVO.getScope().contains(metadataEntityDataItemPO.getDataType())) {
            errorRules.add(ruleName);
            isHaveScope = true;
          } 
        } 
        if (isHaveScope) {
          String str = StringUtils.join(errorRules, "、");
          errMsg = "验证规则【" + str + "】不适用对应字段";
        } 
        if (!StringUtils.isEmpty(errMsg)) {
          errorCell.setColumnIndex(columnIndex);
          errorCell.setMsg(errMsg);
        } else {
          for (i = 0; i < ruleStrs.length; i++) {
            String ruleStr = ruleStrs[i];
            RuleConfigVO ruleConfigVO = allRules.stream().filter(r -> r.getName().equals(ruleStr)).findFirst().orElse(null);
            if (i != 0)
              dataRuleStr = dataRuleStr + ","; 
            dataRuleStr = dataRuleStr + ruleConfigVO.getId();
          } 
          metadataEntityDataItemPO.setDataRule(dataRuleStr);
          fileInfoFieldPO.setDataRule(dataRuleStr);
        } 
      } 
    } 
    return errorCell;
  }
  
  private ErrorCellInfo checkFileInfoFieldOrder(FileInfoFieldPO fileInfoFieldPO, String value, ErrorCellInfo errorCell, int columnIndex, String name, Map<String, String> row, List<Map<String, String>> sheetData, List<FileInfoFieldPO> fileInfoFieldPOListFromDb) {
    String order = row.get("序号");
    if (StringUtils.hasText(value) && StringUtils.hasText(order)) {
      Pattern pattern = Pattern.compile("^-?\\d+$");
      if (!pattern.matcher(order).matches()) {
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg(name + "的值有误");
        return errorCell;
      } 
      Integer reallyOrder = getReallyOrder(order);
      fileInfoFieldPO.setFieldOrder(reallyOrder);
      row.put("序号", String.valueOf(reallyOrder));
    } else if (StringUtils.isEmpty(order)) {
      String reallyOrder = getNotRepeatOrder(sheetData, fileInfoFieldPOListFromDb, order);
      fileInfoFieldPO.setFieldOrder(Integer.valueOf(Integer.parseInt(reallyOrder)));
      row.put("序号", reallyOrder);
    } 
    return errorCell;
  }
  
  private Integer getReallyOrder(String order) {
    return Integer.valueOf(DCConst.MetadataDirectoryType.SYSTEM_FILE_SIZE.intValue() + Integer.parseInt(order));
  }
  
  private ErrorCellInfo checkMetadataEntityDataItemCode(FileInfoFieldPO fileInfoFieldPO, String value, ErrorCellInfo errorCell, int columnIndex, MetadataEntityDataItemDTO metadataEntityDataItemDTO, Map<String, String> row) {
    String dataItemCode = row.get("数据元");
    if (StringUtils.hasText(value) && StringUtils.hasText(dataItemCode))
      if (metadataEntityDataItemDTO != null && !StringUtils.isEmpty(metadataEntityDataItemDTO.getDataItemId())) {
        fileInfoFieldPO.setDataItemId(metadataEntityDataItemDTO.getDataItemId());
        if (StringUtils.isEmpty(fileInfoFieldPO.getFieldName()))
          fileInfoFieldPO.setFieldName(metadataEntityDataItemDTO.getDataItemName()); 
        fileInfoFieldPO.setIsReference(DCConst.TRUE);
      } else {
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg("对应数据元不存在");
      }  
    return errorCell;
  }
  
  private String getNotRepeatOrder(List<Map<String, String>> sheetData, List<FileInfoFieldPO> infoItemPOListFromDb, String order) {
    if (!StringUtils.isEmpty(order) && !infoItemPOListFromDb.stream().anyMatch(item -> (item.getFieldOrder().intValue() == Integer.parseInt(order))))
      return order; 
    Integer maxOrder = Integer.valueOf(1);
    if (!CollectionUtils.isEmpty(infoItemPOListFromDb)) {
      maxOrder = infoItemPOListFromDb.stream().map(FileInfoFieldPO::getFieldOrder).max(Integer::compareTo).get();
      maxOrder = Integer.valueOf((maxOrder == null) ? 1 : (maxOrder.intValue() + 1));
    } 
    return String.valueOf(recurveOrderIsRepeat(sheetData, maxOrder.intValue()));
  }
  
  private int recurveOrderIsRepeat(List<Map<String, String>> sheetData, int order) {
    String orderStr = String.valueOf(order);
    if (!sheetData.stream().anyMatch(item -> (item.get("序号") != null && ((String)item.get("序号")).equalsIgnoreCase(orderStr))))
      return order; 
    return recurveOrderIsRepeat(sheetData, order + 1);
  }
  
  private ErrorCellInfo checkDataRange(FileInfoFieldPO fileInfoFieldPO, MetadataEntityDataItemDTO metadataEntityDataItemPO, String value, ErrorCellInfo errorCell, int columnIndex, String tokenId) {
    if (!StringUtils.isEmpty(value)) {
      MetadataCommonCodeVO metadataCommonCodePO = (MetadataCommonCodeVO)this.dataStandardClient.getMetadataCommonCodeByTableCode(value, getDefaultCode(), tokenId).getObj();
      if (metadataCommonCodePO != null) {
        Long rangeId = metadataCommonCodePO.getCodeTableId();
        metadataEntityDataItemPO.setDataRange(rangeId);
        String dataRangeConfig = getDataRangeConfig(metadataCommonCodePO.getCodeTableId(), tokenId);
        metadataEntityDataItemPO.setData_range_config(StringUtils.isEmpty(dataRangeConfig) ? null : dataRangeConfig);
        fileInfoFieldPO.setDataRange(rangeId);
        fileInfoFieldPO.setDataRangeConfig(StringUtils.isEmpty(dataRangeConfig) ? null : dataRangeConfig);
      } else {
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg("值域信息【" + value + "】不存在");
      } 
    } else if (metadataEntityDataItemPO.getDataItemId() != null) {
      fileInfoFieldPO.setDataRange(metadataEntityDataItemPO.getDataRange());
      fileInfoFieldPO.setDataRangeConfig(metadataEntityDataItemPO.getData_range_config());
    } 
    return errorCell;
  }
  
  private String getDataRangeConfig(Long codeTableId, String tokenId) {
    int level = ((Integer)this.dataStandardClient.getMaxLevelByCodeTableId(codeTableId.toString(), "Standard", tokenId).getObj()).intValue();
    if (level > 0) {
      List<JSONObject> list = new ArrayList<>();
      for (int i = 0; i < level; i++) {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("level", Integer.valueOf(i + 1));
        jsonObject.put("selected", Boolean.valueOf(true));
        jsonObject.put("linkFieldId", null);
        list.add(jsonObject);
      } 
      return JSON.toJSONString(list, new SerializerFeature[] { SerializerFeature.WriteMapNullValue });
    } 
    return "";
  }
  
  private ErrorCellInfo checkDataItemName(FileInfoFieldPO fileInfoFieldPO, MetadataEntityDataItemDTO metadataEntityDataItemDTO, FileInfoTablePO fileInfoTablePO, String value, ErrorCellInfo errorCell, int columnIndex, String name, Integer isPrimaryKey, DataSourceVO dataSource, List<FileInfoFieldPO> fileInfoFieldPOList) {
    if (StringUtils.hasText(value)) {
      String errorMsg = FieldValidateUtil.checkFormatDataItemName(value);
      if (errorMsg != null) {
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg(errorMsg);
        return errorCell;
      } 
      ResultEntity<Boolean> checkInfoItemNameIsSysField = checkFileInfoFieldNameIsSysFieldName(value, isPrimaryKey);
      if (!DCConst.FALSE.equals(checkInfoItemNameIsSysField.getCode())) {
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg(checkInfoItemNameIsSysField.getMsg());
        return errorCell;
      } 
      String dbType = (dataSource != null) ? dataSource.getType() : null;
      errorCell = checkDataItemName(name, value, isPrimaryKey, fileInfoTablePO.getFileTableId(), dbType, fileInfoFieldPOList, errorCell, columnIndex);
      if (metadataEntityDataItemDTO.getDataItemId() == null)
        metadataEntityDataItemDTO.setDataItemName(value); 
      fileInfoFieldPO.setFieldName(value);
    } else {
      errorCell.setColumnIndex(columnIndex);
      errorCell.setMsg(name + "不能为空");
    } 
    return errorCell;
  }
  
  private ErrorCellInfo checkDataItemName(String fieldName, String dataItemName, Integer isPrimaryKey, Long entityId, String dbType, List<FileInfoFieldPO> fileInfoFieldPOList, ErrorCellInfo errorCell, int columnIndex) {
    String errMsg = FieldValidateUtil.checkDataItemName(dataItemName, fieldName);
    if (StringUtils.hasText(errMsg)) {
      errorCell.setColumnIndex(columnIndex);
      errorCell.setMsg(errMsg);
    } 
    BatchCheckDataItemNameParamDTO batchCheckDataItemNameParamDTO = new BatchCheckDataItemNameParamDTO();
    List<CheckDataItemNameDTO> checkDataItemNameList = new ArrayList<>();
    CheckDataItemNameDTO checkDataItemNameDTO = new CheckDataItemNameDTO();
    checkDataItemNameDTO.setDataItemName(dataItemName);
    checkDataItemNameDTO.setIsPrimaryKey(isPrimaryKey);
    checkDataItemNameList.add(checkDataItemNameDTO);
    batchCheckDataItemNameParamDTO.setCheckDataItemNameList(checkDataItemNameList);
    batchCheckDataItemNameParamDTO.setDbType(dbType);
    batchCheckDataItemNameParamDTO.setEntityId(entityId);
    batchCheckDataItemNameParamDTO.setIsDataItemName(true);
    batchCheckDataItemNameParamDTO.setIsResources(DCConst.FALSE);
    ResultEntity<Boolean> isUseRet = ((FileInfoFieldManager)ServiceUtil.getFileInfoFieldManager(getDefaultCode(), FileInfoFieldManager.class)).checkDataItemNameIsUse(batchCheckDataItemNameParamDTO);
    Boolean isUse = (Boolean)isUseRet.getObj();
    if (isUse != null && !isUse.booleanValue())
      isUse = Boolean.valueOf((fileInfoFieldPOList.stream().filter(item -> dataItemName.equalsIgnoreCase(item.getFieldName())).count() > 0L)); 
    if (isUse != null && isUse.booleanValue()) {
      errorCell.setColumnIndex(columnIndex);
      errorCell.setMsg("物理字段名称已存在");
    } else if (isUse == null) {
      errorCell.setColumnIndex(columnIndex);
      errorCell.setMsg(isUseRet.getMsg());
    } 
    return errorCell;
  }
  
  private ErrorCellInfo checkExcelFileInfoFieldName(FileInfoFieldPO fileInfoFieldPO, String value, Integer isPrimaryKey, ErrorCellInfo errorCell, int columnIndex, String name, List<FileInfoFieldPO> infoFieldPOList, List<FileInfoFieldPO> fileInfoFieldPOList) {
    if (StringUtils.isEmpty(value)) {
      errorCell.setColumnIndex(columnIndex);
      errorCell.setMsg(name + "不能为空");
      return errorCell;
    } 
    String errMsg = FieldValidateUtil.checkFieldCodeOrNameLength(value, name);
    if (StringUtils.hasText(errMsg)) {
      errorCell.setColumnIndex(columnIndex);
      errorCell.setMsg(errMsg);
      return errorCell;
    } 
    if (infoFieldPOList.stream().anyMatch(item -> value.equalsIgnoreCase(item.getFieldCnName()))) {
      errorCell.setColumnIndex(columnIndex);
      errorCell.setMsg("字段名称存在重复值");
    } else if (fileInfoFieldPOList.stream().anyMatch(item -> value.equalsIgnoreCase(item.getFieldCnName()))) {
      errorCell.setColumnIndex(columnIndex);
      errorCell.setMsg("字段名称【" + value + "】已存在");
    } else {
      fileInfoFieldPO.setFieldCnName(value);
    } 
    return errorCell;
  }
  
  private ResultEntity<Boolean> checkFileInfoFieldNameIsSysFieldName(String fieldName, Integer isPrimaryKey) {
    if (DCConst.TRUE.equals(isPrimaryKey) && checkFileInfoFieldNameIsSysFieldName(fieldName))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_PRIMARY_KEY_SAME_NAME_FILE_TABLE_SYNC.getCode()), "物理字段名称【" + fieldName + "】为主键时不能和文件表内置字段相同"); 
    return ResultEntity.successMessage(Boolean.valueOf(true));
  }
  
  private boolean checkFileInfoFieldNameIsSysFieldName(String infoItemName) {
    return SysFieldHelper.fileSysFieldContains(infoItemName);
  }
  
  private ErrorCellInfo checkFieldCode(FileInfoFieldPO fileInfoFieldPO, FileInfoTablePO fileInfoTablePO, String value, ErrorCellInfo errorCell, int rowIndex, int columnIndex, String name, List<Map<String, String>> sheetData, Map<String, List<FileInfoFieldPO>> sheetWithItems, String sheetName) {
    if (StringUtils.hasText(value)) {
      List<String> fieldCodes = new ArrayList<>();
      fieldCodes.add(value);
      ResultEntity<Boolean> isCodeExist = batchCheckFileInfoFieldCodeIsExist(fieldCodes, fileInfoTablePO.getDataCategory(), fileInfoTablePO.getFileTableName());
      if (isCodeExist.getCode().intValue() != 0) {
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg("文件表中【" + fileInfoTablePO.getFileTableCnName() + "】" + name + "【" + value + "】已存在");
        return errorCell;
      } 
      String errMsg = FieldValidateUtil.checkFieldCodeOrNameLength(value, name);
      if (StringUtils.hasText(errMsg)) {
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg(errMsg);
        return errorCell;
      } 
      errMsg = checkSameFileInfoFieldCode(name, value, sheetWithItems, sheetData, Integer.valueOf(rowIndex), sheetName);
      if (StringUtils.hasText(errMsg)) {
        errorCell.setColumnIndex(columnIndex);
        errorCell.setMsg(errMsg);
        return errorCell;
      } 
      fileInfoFieldPO.setFieldCode(value);
      return errorCell;
    } 
    return errorCell;
  }
  
  private String checkSameFileInfoFieldCode(String name, String value, Map<String, List<FileInfoFieldPO>> sheetWithItems, List<Map<String, String>> sheetData, Integer rowIndex, String curSheetName) {
    List<String> errorSheet = new ArrayList<>();
    boolean isSame = StringUtils.hasText(checkSame(value, name, sheetData, rowIndex.intValue()));
    if (isSame)
      errorSheet.add(curSheetName); 
    Set<String> sheetNames = sheetWithItems.keySet();
    for (String sheetName : sheetNames) {
      List<FileInfoFieldPO> fileInfoFieldPOList = sheetWithItems.get(sheetName);
      if (fileInfoFieldPOList != null && !fileInfoFieldPOList.isEmpty()) {
        Boolean isExist = Boolean.valueOf((fileInfoFieldPOList.stream().filter(item -> item.getFieldCode().equalsIgnoreCase(value)).count() > 0L));
        if (isExist.booleanValue())
          errorSheet.add(sheetName); 
      } 
    } 
    if (!errorSheet.isEmpty())
      return name + "【" + value + "】在工作簿【" + String.join("、", (Iterable)errorSheet) + "】已存在"; 
    return null;
  }
  
  private String checkSame(String value, String name, List<Map<String, String>> sheetData, int rowIndex) {
    for (int i = rowIndex + 1; i < sheetData.size(); i++) {
      if (sheetData.get(i) != null && StringUtils.hasText(value) && value.equalsIgnoreCase((String)((Map)sheetData.get(i)).get(name)))
        return name + "存在重复数据"; 
    } 
    return null;
  }
  
  private ResultEntity<Boolean> batchCheckFileInfoFieldCodeIsExist(List<String> fieldCodes, Integer category, String fileTableName) {
    if (fieldCodes.isEmpty())
      return ResultEntity.successMessage(Boolean.valueOf(true)); 
    Set<String> exist = new LinkedHashSet<>();
    if (fieldCodes.size() > 1) {
      List<String> duplicate = (List<String>)((Map)fieldCodes.stream().collect(Collectors.groupingBy(Function.identity(), Collectors.counting()))).entrySet().stream().filter(item -> (((Long)item.getValue()).longValue() > 1L)).map(Map.Entry::getKey).collect(Collectors.toList());
      exist.addAll(duplicate);
    } 
    for (String fieldCode : fieldCodes) {
      if (!exist.contains(fieldCode) && checkFileInfoFieldCodeIsExist(fieldCode, category, null))
        exist.add(fieldCode); 
    } 
    if (exist.isEmpty())
      return ResultEntity.successMessage(Boolean.valueOf(true)); 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_FIELD_CODE_EXIST.getCode()), "文件表【" + fileTableName + "】中" + "字段编码【" + String.join("、", (Iterable)exist) + "】已存在");
  }
  
  private boolean checkFileInfoFieldCodeIsExist(String fieldCode, Integer category, Long infoItemId) {
    if (StringUtils.isEmpty(fieldCode))
      return false; 
    List<Long> fieldIdsByCode = ((IFileInfoFieldDao)ServiceUtil.getFileInfoFieldDao(getDefaultCode(), IFileInfoFieldDao.class)).getFieldIdsByCodeAndCategory(fieldCode, category);
    if (infoItemId == null)
      return (fieldIdsByCode.size() > 0); 
    return fieldIdsByCode.stream().anyMatch(item -> !infoItemId.equals(item));
  }
  
  private MetadataEntityDataItemVO getMetadataEntityDataItemByDataItemCode(Map<String, String> row, String tokenId) {
    String dataItemCode = row.get("数据元");
    if (StringUtils.hasText(dataItemCode) && StringUtils.hasText(dataItemCode))
      return (MetadataEntityDataItemVO)this.dataStandardClient.getMetadataEntityDataItemByDataItemCode(dataItemCode, getDefaultCode(), tokenId).getObj(); 
    return null;
  }
  
  private Integer getBoolFieldValue(String fieldName, Map<String, String> row) {
    Integer result = null;
    try {
      if (StringUtils.isEmpty(row.get(fieldName))) {
        result = Integer.valueOf(0);
      } else if (!StringUtils.isEmpty(row.get(fieldName)) && PRIMARY_KEY_VALUES.indexOf(row.get(fieldName)) > -1) {
        result = Integer.valueOf(((String)row.get(fieldName)).equals("是") ? 1 : 0);
      } else if (!StringUtils.isEmpty(row.get(fieldName)) && !PRIMARY_KEY_VALUES.contains(row.get(fieldName))) {
        result = null;
      } 
    } catch (Exception ex) {
      result = null;
    } 
    return result;
  }
  
  private ResultEntity getFileInfoTableWithSheet(Workbook workbook, MultipartFile file, FileInfoTablePO fileInfoTablePO, String platCode) throws Exception {
    Map<String, String> errorMap = new HashMap<>();
    Map<FileInfoTablePO, List<LinkedHashMap<String, String>>> fileInfoTableWithSheet = null;
    boolean isHaveSheet = true;
    int sheetIndex = 0;
    while (isHaveSheet) {
      String sheetName = null;
      try {
        Sheet sheet = workbook.getSheetAt(sheetIndex);
        if (sheet == null) {
          isHaveSheet = false;
          break;
        } 
        sheetName = sheet.getSheetName();
      } catch (Exception ex) {
        isHaveSheet = false;
      } 
      if (fileInfoTablePO != null && isHaveSheet && !StringUtils.isEmpty(sheetName) && sheetName.equals(fileInfoTablePO.getFileTableCnName())) {
        if (fileInfoTableWithSheet == null)
          fileInfoTableWithSheet = new HashMap<>(); 
        List<LinkedHashMap<String, String>> sheetData = ExcelUtil.readExcel(file.getInputStream(), sheetName);
        if (!sheetData.isEmpty()) {
          String sheetFieldValidateStr = validateSheetFields(sheetData, platCode);
          if (!StringUtils.isEmpty(sheetFieldValidateStr))
            errorMap.put(sheetName, sheetFieldValidateStr); 
          fileInfoTableWithSheet.put(fileInfoTablePO, sheetData);
        } 
      } 
      sheetIndex++;
    } 
    if (!errorMap.isEmpty()) {
      Set<String> keys = errorMap.keySet();
      String errorSheets = String.join("，", (Iterable)keys);
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_IMPORT_EXCEL_DATA_GET_SHEET_FIELD_ERROR.getCode()), "导入失败，原因：获取需要导入的工作簿【" + errorSheets + "】字段信息缺失");
    } 
    return ResultEntity.successMessage(fileInfoTableWithSheet);
  }
  
  private String checkHaveRepeatValue(List<Map<String, String>> sheetData, String platCode) {
    Set<String> repeatFieldCnNameValues = new HashSet<>();
    Set<String> fieldCnNameValues = new HashSet<>();
    for (Map<String, String> data : sheetData) {
      if (data == null)
        continue; 
      String fieldCnName = data.get("字段名称");
      if (fieldCnNameValues.contains(fieldCnName)) {
        repeatFieldCnNameValues.add(fieldCnName);
        continue;
      } 
      fieldCnNameValues.add(fieldCnName);
    } 
    if (repeatFieldCnNameValues.size() > 0)
      return "【字段名称】【" + String.join("，", (Iterable)repeatFieldCnNameValues) + "】存在重复值"; 
    return "";
  }
  
  private String validateSheetFields(List<LinkedHashMap<String, String>> sheetData, String platCode) {
    Map<String, String> firstRow = null;
    for (Map<String, String> data : sheetData) {
      if (data != null)
        firstRow = data; 
    } 
    if (firstRow == null)
      return ""; 
    Set<String> keys = firstRow.keySet();
    List<String> defectFields = new ArrayList<>();
    List<String> fieldNames = new ArrayList<>(COMMON_FIELD_NAMES);
    Collections.replaceAll(fieldNames, "对应数据元", "对应数据元物理字段名");
    for (String name : fieldNames) {
      if (!keys.contains(name))
        defectFields.add(name); 
    } 
    if (!defectFields.isEmpty())
      return "【" + String.join("，", (Iterable)defectFields) + "】不存在"; 
    return "";
  }
  
  public ResultEntity<String> downLoadExcelTemplate(HttpServletResponse response, MultipartFile file, Long fileTableId, Integer nodeType, Integer dataCategory, String platCode, String tokenId) {
    FileInfoTablePO fileInfoTable = ((IFileInfoTableDao)ServiceUtil.getFileInfoTableDao(getDefaultCode(), IFileInfoTableDao.class)).selectFileInfoTable(fileTableId);
    if (fileInfoTable != null) {
      XSSFWorkbook workbook = null;
      try {
        workbook = new XSSFWorkbook(file.getInputStream());
        workbook.setSheetName(0, fileInfoTable.getFileTableCnName());
        if (response != null) {
          response.setContentType("application/vnd.ms-excel;charset=utf-8");
          response.setHeader("Content-Disposition", "attachment;filename=\"" + new String(file.getOriginalFilename().getBytes("gb2312"), "ISO8859-1"));
          ServletOutputStream servletOutputStream = response.getOutputStream();
          workbook.write((OutputStream)servletOutputStream);
          servletOutputStream.close();
          return null;
        } 
      } catch (Exception ex) {
        logErrorInfo(ExceptionUtil.getStackTraceMsg(ex), "从文件流中读取excel异常", platCode, tokenId);
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_STANDARD_IMPORT_EXCEL_DATA_ERROR_FIELD.getCode()), StatusCodeEnum.DATA_STANDARD_IMPORT_EXCEL_DATA_ERROR_FIELD.getMessage());
      } 
      return null;
    } 
    if (nodeType.equals(Integer.valueOf(1)))
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_EXCEL_DOWN_LOAD_NO_TABLE_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_EXCEL_DOWN_LOAD_NO_TABLE_FAILED.getMessage()); 
    return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_EXCEL_DOWN_LOAD_NO_TABLES_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_EXCEL_DOWN_LOAD_NO_TABLES_FAILED.getMessage());
  }
  
  private void logErrorInfo(String stackInfo, String msg, String platCode, String tokenId) {
    CommonLogDTO logDTO = new CommonLogDTO();
    logDTO.setPlatCode(platCode);
    logDTO.setTokenId(tokenId);
    logDTO.setStackInformation(stackInfo);
    logDTO.setLoggerInformation(msg);
    logDTO.setLogLevel(FrameConst.Log.LOG_LEVEL_ERROR);
    logDTO.setLogType(0);
    logDTO.setModule_code(HeaderInterceptor.getModuleCode());
    RabbitMQUtil.publish("DC.Standard.log", logDTO);
  }
}
